#ifndef STRATE_ISOLANTE_H
#define STRATE_ISOLANTE_H

#include <winsock2.h> // soupir
#include <string>

//
// socket_t est le type des sockets sur la plateforme
//
typedef SOCKET socket_t;
//
// est_invalide() reoit un socket de la plateforme et indique
// si celui-ci est valide ou non selon les politiques locales
//
bool est_invalide(const socket_t) throw();
//
// socket_operation_t est le type du rsultat d'une opration
// sur un socket pour la plateforme
//
typedef int socket_operation_t;
//
// est_erreur() reoit un rsultat d'opration sur un socket et
// indique si celui-ci constitue ou non une erreur selon les
// politiques locales
//
bool est_erreur(const socket_operation_t) throw();
//
// erreur() met un message d'erreur contextuel sur le flux
// standard d'erreurs et retourne le code local de l'erreur
// d'opration sur un socket
//
int erreur(const std::string &);
//
// charger_sockets() charge les modules de gestion des sockets
// sur la plateforme (s'il y a lieu)
//
void charger_sockets();
//
// decharger_sockets() dcharge les modules de gestion des
// sockets sur la plateforme (s'il y a lieu)
//
void decharger_sockets() throw();
//
// creer_socket() cre et retourne un socket
//
socket_t creer_socket();
//
// connecter() connecte un socket  une adresse IP et un
// port (prsum normalis au pralable). Valide seulement
// ct client
//
void connecter(socket_t, const std::string &, const short);
//
// reserver_port() rserve un port (prsum normalis au
// pralable) pour un socket donn. Valide seulement du
// ct serveur
//
void reserver_port(const socket_t, const short);
//
// accepter_client() tente d'accepter une demande de
// connexion d'un client puis retourne le socket de
// conversation rsultant. Valide seulement ct serveur.
//
socket_t accepter_client(const socket_t);
//
// recevoir() reoit du texte simpliste sur un socket
// jusqu' la rception d'un dlimiteur, puis retourne
// le texte reu. Cette fonction est trop simple pour
// tre utilise dans du code de production.
//
std::string recevoir(const socket_t, const char);
//
// envoyer() met du texte sur un socket puis annexe
// un dlimiteur au texte envoy. Cette fonction est
// trop simple pour du code de production.
//
void envoyer(const socket_t, std::string, const char);
//
// fermer_socket() ferme un socket aprs avoir termin
// toute opratrion encore en cours sur celui-ci.
//
void fermer_socket(const socket_t) throw();

//
//
//
void invalider_socket(socket_t &);

#endif
